FeatherBuffer

Struct FeatherBuffer 

pub struct FeatherBuffer { /* private fields */ }
A FeatherBuffer encodes data via an Arrow StreamWriter.

It flushes the internal byte buffer according to rotation policy.

Implementations

Source

impl FeatherBuffer

pub fn new( schema: &Schema, rotation_config: RotationConfig, ) -> Result<Self, ArrowError>

Creates a new FeatherBuffer using the given path, schema and maximum buffer size.

Errors

Returns an error if the Arrow stream writer cannot be created.

pub fn write_record_batch( &mut self, batch: &RecordBatch, ) -> Result<bool, ArrowError>

Writes the given RecordBatch to the internal buffer.

Returns true if it should be rotated according rotation policy

Errors

Returns an error if Arrow IPC writing fails.

pub fn take_buffer(&mut self) -> Result<Vec<u8>, ArrowError>

Consumes the writer and returns the buffer of bytes from the StreamWriter

Errors

Returns an error if the replacement writer cannot be created or the previous writer cannot be finalized.

pub const fn should_rotate(&self) -> bool

Should rotate