pub struct FeatherBuffer { /* private fields */ }Expand description
A FeatherBuffer encodes data via an Arrow StreamWriter.
It flushes the internal byte buffer according to rotation policy.
Implementations
Sourceimpl FeatherBuffer
impl FeatherBuffer
Sourcepub fn new(
schema: &Schema,
rotation_config: RotationConfig,
) -> Result<Self, ArrowError>
pub fn new( schema: &Schema, rotation_config: RotationConfig, ) -> Result<Self, ArrowError>
Creates a new FeatherBuffer using the given path, schema and maximum buffer size.
Errors
Returns an error if the Arrow stream writer cannot be created.
Sourcepub fn write_record_batch(
&mut self,
batch: &RecordBatch,
) -> Result<bool, ArrowError>
pub fn write_record_batch( &mut self, batch: &RecordBatch, ) -> Result<bool, ArrowError>
Writes the given RecordBatch to the internal buffer.
Returns true if it should be rotated according rotation policy
Errors
Returns an error if Arrow IPC writing fails.
Sourcepub fn take_buffer(&mut self) -> Result<Vec<u8>, ArrowError>
pub fn take_buffer(&mut self) -> Result<Vec<u8>, ArrowError>
Consumes the writer and returns the buffer of bytes from the StreamWriter
Errors
Returns an error if the replacement writer cannot be created or the previous writer cannot be finalized.
Sourcepub const fn should_rotate(&self) -> bool
pub const fn should_rotate(&self) -> bool
Should rotate